/*
 * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
 * Copyright (C) 2005 QSDN,Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __LOAD_DEVICE_DATA_H__
#define __LOAD_DEVICE_DATA_H__

#include "mod_chxj.h"

extern void chxj_load_device_data(
  Doc*                     doc, 
  apr_pool_t*              p, 
  mod_chxj_config*         conf);

extern void chxj_load_device_tsv_data(
  apr_file_t*              fp,
  apr_pool_t*              p, 
  mod_chxj_config*         conf);

#endif
